library(readxl)
data_xlx<-read_excel("/Users/zxj/Desktop/file 1/data.xlsx")
A<-as.matrix(data_xlx[,1:23])               
Z<-scale(A)                          
X<-as.data.frame(Z)

library(PerformanceAnalytics)
XX=chart.Correlation(Z, method = "spearman")
R<-cor(data_xlx, method = "spearman")

library(AER)
fit.full <- glm(A_adenophora~altitude+slope+aspect+soil_moisture+soil_temperature+burn_intensity+community_canopy_density+shrub_layer_coverage+herb_layer_coverage+Simpson_diversity_index_of_tree_layer+Simpson_diversity_index_of_shrub_layer+Simpson_diversity_index_of_herb_layer+shortest_distance_to_roads+shortest_distance_to_waters+shortest_distance_to_residential+temperature_annual_range+precipitation_seasonality+precipitation_of_driest_month+precipitation_of_wettest_month+temperature_seasonality+annual_precipitation+mean_temperature_of_coldest_quarter,data=X,family=gaussian())
summary(fit.full)
fit.reduce <- glm(A_adenophora~slope+aspect+soil_moisture+community_canopy_density+shrub_layer_coverage+herb_layer_coverage+Simpson_diversity_index_of_shrub_layer+Simpson_diversity_index_of_herb_layer+shortest_distance_to_roads+shortest_distance_to_residential+temperature_seasonality+temperature_annual_range+precipitation_of_wettest_month+precipitation_of_driest_month,data=X,family=gaussian())
summary(fit.reduce)

relweights <-
  function(fit,...){                        
    R <- cor(fit$model)  
    nvar <- ncol(R)         
    rxx <- R[2:nvar, 2:nvar]
    rxy <- R[2:nvar, 1]     
    svd <- eigen(rxx)       
    evec <- svd$vectors                          
    ev <- svd$values        
    delta <- diag(sqrt(ev)) 
    lambda <- evec %*% delta %*% t(evec)       
    lambdasq <- lambda ^ 2  
    beta <- solve(lambda) %*% rxy          
    rsquare <- colSums(beta ^ 2)                  
    rawwgt <- lambdasq %*% beta ^ 2   
    import <- (rawwgt / rsquare) * 100
    lbls <- names(fit$model[2:nvar])  
    rownames(import) <- lbls
    colnames(import) <- "Weights"
    #import<-import[order(import["Weights"],decreasing=TRUE)]
    View(import)
    barplot(t(import),names.arg=lbls,
            ylab="",
            xlab="",
            width=0.2,
            cex.axis = 0.8,
            cex.names = 0.4,
            las=2,
            xlim=c(0,30),
            main="Relative importance of predictor variables",
            sub=paste("R-Square=", round(rsquare, digits=3)),
            ...) 
    return(import)
  }
relweights(fit.reduce, col = "blue",horiz=TRUE)

install.packages("sjPlot")
library(sjPlot)
library(ggplot2)
(plot_model(fit.reduce,vline.color = "black",show.values = TRUE, value.offset = .3,show.legend =T,)+
    #scale_y_continuous (limits = c(0,1),breaks = seq(0,1,by=0.1))+
    ggtitle("")+
    ylab("Estimate")+
    xlab("Predictive variables")+
    theme_bw ()+theme(text = element_text(family = "",size = 18),panel.grid=element_blank(),
                      plot.title = element_text(hjust = 4,colour = NA)))

library(vegan)
data_xlx0<-read_excel("/Users/zxj/Desktop/file 1/data.xlsx")
data_xlx1<-data_xlx0[,1]
data_xlx2<-data_xlx0[,2:13]
data_xlx3<-data_xlx0[,14:16]
data_xlx4<-data_xlx0[,17:23]
sp=log10(gtsdata)
dz=data_xlx2
dx=data_xlx3
qh=data_xlx4
local=dz
landscape=dx
regional=qh
mod<-varpart(data_xlx1,local,landscape,regional)
mod
showvarparts(3, bg=2:4)
plot(mod, bg=2:4)

library(ggplot2)
df2<-read.csv('/Users/zxj/Desktop/file 1/Relative_importance.csv')
p1<- ggplot(df2,aes(x=Predictive.variables, y=Relative.importance,group=Predictive.variables,color=Predictive.variables)) +
  stat_summary(geom="bar", fun = mean,width=0.5,color="black",position = position_dodge(),fill="pink")+
  theme_classic()+theme(text=element_text(size=15,family="serif"))+ 
  guides(fill=guide_legend(title=))+ylim(0,30)+ 
  xlab("Predictive.variables") + ylab("Relative.importance")+coord_flip()
df3<-read.csv('/Users/zxj/Desktop/file 1/Relative_importance1.csv')
p10<- ggplot(df3,aes(x=Predictive.variables, y=Relative.importance,group=Predictive.variables,color=Predictive.variables)) +
  stat_summary(geom="bar", fun = mean,width=0.5,color="black",position = position_dodge(),fill="palegreen")+
  theme_classic()+
  theme(text=element_text(size=15,family="serif"))+ 
  guides(fill=guide_legend(title=))+ylim(0,30)+ 
  xlab("Predictive.variables") + ylab("Relative.importance")+coord_flip()
df4<-read.csv('/Users/zxj/Desktop/file 1/Relative_importance2.csv')
p13<- ggplot(df4,aes(x=Predictive.variables, y=Relative.importance,group=Predictive.variables,color=Predictive.variables)) +
  stat_summary(geom="bar", fun = mean,width=0.5,color="black",position = position_dodge(),fill="lightblue")+
  theme_classic()+
  theme(text=element_text(size=15,family="serif"))+ 
  guides(fill=guide_legend(title=))+ylim(0,30)+
  xlab("Predictive.variables") + ylab("Relative.importance")+coord_flip()

data_xlx<-read_excel("/Users/zxj/Desktop/file 1/data.xlsx")
p2<- ggplot(data = data_xlx,aes(x=soil_moisture,y=A_adenophora))+geom_point(pch=16,color="pink")+
  labs(x="soil_moisture",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))
p3<- ggplot(data = data_xlx,aes(x=slope,y=A_adenophora))+geom_point(pch=16,color="pink")+
  labs(x="slope",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))
p4<- ggplot(data = data_xlx,aes(x=Sds,y=A_adenophora))+geom_point(pch=16,color="pink")+
  labs(x="Sds",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))
p5<- ggplot(data = data_xlx,aes(x=Sdh,y=A_adenophora))+geom_point(pch=16,color="pink")+
  labs(x="Sdh",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))
p6<- ggplot(data = data_xlx,aes(x=shrub_layer_coverage,y=A_adenophora))+geom_point(pch=16,color="pink")+
  labs(x="shrub_layer_coverage",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))
p7<- ggplot(data = data_xlx,aes(x=herb_layer_coverage,y=A_adenophora))+geom_point(pch=16,color="pink")+
  labs(x="herb_layer_coverage",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))
p8<- ggplot(data = data_xlx,aes(x=community_canopy_density,y=A_adenophora))+geom_point(pch=16,color="pink")+
  labs(x="community_canopy_density",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))
p9<- ggplot(data = data_xlx,aes(x=aspect,y=A_adenophora))+geom_point(pch=16,color="pink")+
  labs(x="aspect",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))

p11<- ggplot(data = data_xlx,aes(x=shortest_distance_to_roads,y=A_adenophora))+geom_point(pch=16,color="palegreen")+
  labs(x="shortest_distance_to_roads",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))
p12<- ggplot(data = data_xlx,aes(x=shortest_distance_to_residential,y=A_adenophora))+geom_point(pch=16,color="palegreen")+
  labs(x="shortest_distance_to_residential",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))
dev.new()
p14<- ggplot(data = data_xlx,aes(x=temperature_seasonality,y=A_adenophora))+geom_point(pch=16,color="lightblue")+
  labs(x="temperature_seasonality",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))
p15<- ggplot(data = data_xlx,aes(x=temperature_annual_range,y=A_adenophora))+geom_point(pch=16,color="lightblue")+
  labs(x="temperature_annual_range",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))
p16<- ggplot(data = data_xlx,aes(x=precipitation_of_wettest_month,y=A_adenophora))+geom_point(pch=16,color="lightblue")+
  labs(x="precipitation_of_wettest_month",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))
p17<- ggplot(data = data_xlx,aes(x=precipitation_of_driest_month,y=A_adenophora))+geom_point(pch=16,color="lightblue")+
  labs(x="precipitation_of_driest_month",y="A.adenophora")+geom_smooth(linetype=2,color="red")+theme_bw()+
  theme_classic()+scale_color_manual(values = c("red"))

install.packages("patchwork")
library(patchwork)
dev.new()
{p1|(p2+p3+p4+p5)/(p6+p7+p8+p9)}+plot_layout(ncol = 2, width = c(1,2))
{p10|(p11+p12)}+plot_layout(ncol = 2, width = c(1,2))
{p13|(p14+p15+p16+p17)}+plot_layout(ncol = 2, width = c(1,2))


